AstryxBorderToken enum

Border widths, in logical pixels.

1 tokens. cssName is the upstream CSS custom property and is the join key against dev/fixtures/tokens.json.

Inheritance
Implemented types
Available extensions

Values

width → const AstryxBorderToken

The --border-width token.

Default: 1px

const AstryxBorderToken('--border-width')

Properties

cssName String
The upstream CSS custom property name, such as --color-accent.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AstryxBorderToken>
A constant List of the values in this enum, in order of their declaration.