AstryxColorToken enum
Semantic colour tokens.
79 tokens. cssName is the upstream CSS custom property and
is the join key against dev/fixtures/tokens.json.
- Inheritance
- Implemented types
- Available extensions
Values
- accent → const AstryxColorToken
-
The
--color-accenttoken.Default:
light-dark(#0064E0, #2694FE)const AstryxColorToken('--color-accent') - accentMuted → const AstryxColorToken
-
The
--color-accent-mutedtoken.Default:
light-dark(#0082FB33, #0082FB3F)const AstryxColorToken('--color-accent-muted') - onAccent → const AstryxColorToken
-
The
--color-on-accenttoken.Default:
light-dark(#FFFFFF, #FFFFFF)const AstryxColorToken('--color-on-accent') - neutral → const AstryxColorToken
-
The
--color-neutraltoken.Default:
light-dark(rgba(5, 54, 89, 0.1), rgba(223, 226, 229, 0.2))const AstryxColorToken('--color-neutral') - backgroundSurface → const AstryxColorToken
-
The
--color-background-surfacetoken.Default:
light-dark(#FFFFFF, #1F1F22)const AstryxColorToken('--color-background-surface') - backgroundBody → const AstryxColorToken
-
The
--color-background-bodytoken.Default:
light-dark(#F1F4F7, #111112)const AstryxColorToken('--color-background-body') - overlay → const AstryxColorToken
-
The
--color-overlaytoken.Default:
light-dark(#01122866, #11111299)const AstryxColorToken('--color-overlay') - overlayHover → const AstryxColorToken
-
The
--color-overlay-hovertoken.Default:
light-dark(#0536590C, #FFFFFF0C)const AstryxColorToken('--color-overlay-hover') - overlayPressed → const AstryxColorToken
-
The
--color-overlay-pressedtoken.Default:
light-dark(#05365919, #FFFFFF19)const AstryxColorToken('--color-overlay-pressed') - backgroundMuted → const AstryxColorToken
-
The
--color-background-mutedtoken.Default:
light-dark(#0536590C, #1111127F)const AstryxColorToken('--color-background-muted') - textPrimary → const AstryxColorToken
-
The
--color-text-primarytoken.Default:
light-dark(#0A1317, #DFE2E5)const AstryxColorToken('--color-text-primary') - textSecondary → const AstryxColorToken
-
The
--color-text-secondarytoken.Default:
light-dark(#4E606F, #AAAFB5)const AstryxColorToken('--color-text-secondary') - textDisabled → const AstryxColorToken
-
The
--color-text-disabledtoken.Default:
light-dark(#A4B0BC, #6F747C)const AstryxColorToken('--color-text-disabled') - textAccent → const AstryxColorToken
-
The
--color-text-accenttoken.Default:
light-dark(#0064E0, #3E9EFB)const AstryxColorToken('--color-text-accent') - onDark → const AstryxColorToken
-
The
--color-on-darktoken.Default:
light-dark(#FFFFFF, #FFFFFF)const AstryxColorToken('--color-on-dark') - onLight → const AstryxColorToken
-
The
--color-on-lighttoken.Default:
light-dark(#000000, #000000)const AstryxColorToken('--color-on-light') - iconAccent → const AstryxColorToken
-
The
--color-icon-accenttoken.Default:
light-dark(#0064E0, #2694FE)const AstryxColorToken('--color-icon-accent') - iconPrimary → const AstryxColorToken
-
The
--color-icon-primarytoken.Default:
light-dark(#0A1317, #DFE2E5)const AstryxColorToken('--color-icon-primary') - iconSecondary → const AstryxColorToken
-
The
--color-icon-secondarytoken.Default:
light-dark(#4E606F, #AAAFB5)const AstryxColorToken('--color-icon-secondary') - iconDisabled → const AstryxColorToken
-
The
--color-icon-disabledtoken.Default:
light-dark(#A4B0BC, #6F747C)const AstryxColorToken('--color-icon-disabled') - backgroundCard → const AstryxColorToken
-
The
--color-background-cardtoken.Default:
light-dark(#FFFFFF, #1F1F22)const AstryxColorToken('--color-background-card') - backgroundPopover → const AstryxColorToken
-
The
--color-background-popovertoken.Default:
light-dark(#FFFFFF, #28292C)const AstryxColorToken('--color-background-popover') - backgroundInverted → const AstryxColorToken
-
The
--color-background-invertedtoken.Default:
light-dark(#0A1317, #FFFFFF)const AstryxColorToken('--color-background-inverted') - backgroundErrorInverted → const AstryxColorToken
-
The
--color-background-error-invertedtoken.Default:
light-dark(#AA071E, #E3193B)const AstryxColorToken('--color-background-error-inverted') - success → const AstryxColorToken
-
The
--color-successtoken.Default:
light-dark(#0D8626, #0D8626)const AstryxColorToken('--color-success') - successMuted → const AstryxColorToken
-
The
--color-success-mutedtoken.Default:
light-dark(#0B991F33, #0B991F3F)const AstryxColorToken('--color-success-muted') - onSuccess → const AstryxColorToken
-
The
--color-on-successtoken.Default:
light-dark(#FFFFFF, #FFFFFF)const AstryxColorToken('--color-on-success') - error → const AstryxColorToken
-
The
--color-errortoken.Default:
light-dark(#E3193B, #F5394F)const AstryxColorToken('--color-error') - errorMuted → const AstryxColorToken
-
The
--color-error-mutedtoken.Default:
light-dark(#E3193B33, #F5394F3F)const AstryxColorToken('--color-error-muted') - onError → const AstryxColorToken
-
The
--color-on-errortoken.Default:
light-dark(#FFFFFF, #FFFFFF)const AstryxColorToken('--color-on-error') - warning → const AstryxColorToken
-
The
--color-warningtoken.Default:
light-dark(#E9AF08, #F2C00B)const AstryxColorToken('--color-warning') - warningMuted → const AstryxColorToken
-
The
--color-warning-mutedtoken.Default:
light-dark(#E2A40033, #E2A4003F)const AstryxColorToken('--color-warning-muted') - onWarning → const AstryxColorToken
-
The
--color-on-warningtoken.Default:
light-dark(#0A1317, #0A1317)const AstryxColorToken('--color-on-warning') - border → const AstryxColorToken
-
The
--color-bordertoken.Default:
light-dark(#05365919, #F2F4F619)const AstryxColorToken('--color-border') - borderEmphasized → const AstryxColorToken
-
The
--color-border-emphasizedtoken.Default:
light-dark(#CCD3DB, #494D53)const AstryxColorToken('--color-border-emphasized') - skeleton → const AstryxColorToken
-
The
--color-skeletontoken.Default:
light-dark(#CCD3DB, #5A5E66)const AstryxColorToken('--color-skeleton') - track → const AstryxColorToken
-
The
--color-tracktoken.Default:
light-dark(#CCD3DB, #5A5E66)const AstryxColorToken('--color-track') - shadow → const AstryxColorToken
-
The
--color-shadowtoken.Default:
light-dark(rgba(5, 54, 89, 0.1), rgba(0, 0, 0, 0.3))const AstryxColorToken('--color-shadow') - tintHover → const AstryxColorToken
-
The
--color-tint-hovertoken.Default:
light-dark(black, white)const AstryxColorToken('--color-tint-hover') - backgroundBlue → const AstryxColorToken
-
The
--color-background-bluetoken.Default:
light-dark(#0171E333, #0171E333)const AstryxColorToken('--color-background-blue') - borderBlue → const AstryxColorToken
-
The
--color-border-bluetoken.Default:
light-dark(#0064E0, #2694FE)const AstryxColorToken('--color-border-blue') - iconBlue → const AstryxColorToken
-
The
--color-icon-bluetoken.Default:
light-dark(#0064E0, #2694FE)const AstryxColorToken('--color-icon-blue') - textBlue → const AstryxColorToken
-
The
--color-text-bluetoken.Default:
light-dark(#042F97, #AFD7FF)const AstryxColorToken('--color-text-blue') - backgroundCyan → const AstryxColorToken
-
The
--color-background-cyantoken.Default:
light-dark(#03A7D733, #03A7D733)const AstryxColorToken('--color-background-cyan') - borderCyan → const AstryxColorToken
-
The
--color-border-cyantoken.Default:
light-dark(#089DD0, #0171A4)const AstryxColorToken('--color-border-cyan') - iconCyan → const AstryxColorToken
-
The
--color-icon-cyantoken.Default:
light-dark(#00ACC1, #26C6DA)const AstryxColorToken('--color-icon-cyan') - textCyan → const AstryxColorToken
-
The
--color-text-cyantoken.Default:
light-dark(#014975, #A1EEF9)const AstryxColorToken('--color-text-cyan') - backgroundGray → const AstryxColorToken
-
The
--color-background-graytoken.Default:
light-dark(#0A131733, #666A724C)const AstryxColorToken('--color-background-gray') - borderGray → const AstryxColorToken
-
The
--color-border-graytoken.Default:
light-dark(#647685, #748695)const AstryxColorToken('--color-border-gray') - iconGray → const AstryxColorToken
-
The
--color-icon-graytoken.Default:
light-dark(#4E606F, #AAAFB5)const AstryxColorToken('--color-icon-gray') - textGray → const AstryxColorToken
-
The
--color-text-graytoken.Default:
light-dark(#0A1317, #E7EAED)const AstryxColorToken('--color-text-gray') - backgroundGreen → const AstryxColorToken
-
The
--color-background-greentoken.Default:
light-dark(#24BB5E33, #24BB5E33)const AstryxColorToken('--color-background-green') - borderGreen → const AstryxColorToken
-
The
--color-border-greentoken.Default:
light-dark(#0D8626, #0B991F)const AstryxColorToken('--color-border-green') - iconGreen → const AstryxColorToken
-
The
--color-icon-greentoken.Default:
light-dark(#0D8626, #26A756)const AstryxColorToken('--color-icon-green') - textGreen → const AstryxColorToken
-
The
--color-text-greentoken.Default:
light-dark(#09441F, #A5F690)const AstryxColorToken('--color-text-green') - backgroundOrange → const AstryxColorToken
-
The
--color-background-orangetoken.Default:
light-dark(#F2790233, #F2790233)const AstryxColorToken('--color-background-orange') - borderOrange → const AstryxColorToken
-
The
--color-border-orangetoken.Default:
light-dark(#EB6E00, #B34A01)const AstryxColorToken('--color-border-orange') - iconOrange → const AstryxColorToken
-
The
--color-icon-orangetoken.Default:
light-dark(#E9690B, #FB8C00)const AstryxColorToken('--color-icon-orange') - textOrange → const AstryxColorToken
-
The
--color-text-orangetoken.Default:
light-dark(#6B2203, #FDB876)const AstryxColorToken('--color-text-orange') - backgroundPink → const AstryxColorToken
-
The
--color-background-pinktoken.Default:
light-dark(#E638B333, #E638B333)const AstryxColorToken('--color-background-pink') - borderPink → const AstryxColorToken
-
The
--color-border-pinktoken.Default:
light-dark(#F351C0, #C02294)const AstryxColorToken('--color-border-pink') - iconPink → const AstryxColorToken
-
The
--color-icon-pinktoken.Default:
light-dark(#C2185B, #EC407A)const AstryxColorToken('--color-icon-pink') - textPink → const AstryxColorToken
-
The
--color-text-pinktoken.Default:
light-dark(#650053, #FEADE3)const AstryxColorToken('--color-text-pink') - backgroundPurple → const AstryxColorToken
-
The
--color-background-purpletoken.Default:
light-dark(#7952FF33, #7952FF33)const AstryxColorToken('--color-background-purple') - borderPurple → const AstryxColorToken
-
The
--color-border-purpletoken.Default:
light-dark(#9081FF, #7340FE)const AstryxColorToken('--color-border-purple') - iconPurple → const AstryxColorToken
-
The
--color-icon-purpletoken.Default:
light-dark(#5B08D8, #7952FF)const AstryxColorToken('--color-icon-purple') - textPurple → const AstryxColorToken
-
The
--color-text-purpletoken.Default:
light-dark(#3E0697, #B3B0FE)const AstryxColorToken('--color-text-purple') - backgroundRed → const AstryxColorToken
-
The
--color-background-redtoken.Default:
light-dark(#E3193B33, #E3193B33)const AstryxColorToken('--color-background-red') - borderRed → const AstryxColorToken
-
The
--color-border-redtoken.Default:
light-dark(#E3193B, #F5394F)const AstryxColorToken('--color-border-red') - iconRed → const AstryxColorToken
-
The
--color-icon-redtoken.Default:
light-dark(#D31130, #E3193B)const AstryxColorToken('--color-icon-red') - textRed → const AstryxColorToken
-
The
--color-text-redtoken.Default:
light-dark(#7B0210, #FFB2B8)const AstryxColorToken('--color-text-red') - backgroundTeal → const AstryxColorToken
-
The
--color-background-tealtoken.Default:
light-dark(#0DB7AF33, #0DB7AF33)const AstryxColorToken('--color-background-teal') - borderTeal → const AstryxColorToken
-
The
--color-border-tealtoken.Default:
light-dark(#08A3A3, #08767D)const AstryxColorToken('--color-border-teal') - iconTeal → const AstryxColorToken
-
The
--color-icon-tealtoken.Default:
light-dark(#009688, #26A69A)const AstryxColorToken('--color-icon-teal') - textTeal → const AstryxColorToken
-
The
--color-text-tealtoken.Default:
light-dark(#083943, #40DCCD)const AstryxColorToken('--color-text-teal') - backgroundYellow → const AstryxColorToken
-
The
--color-background-yellowtoken.Default:
light-dark(#E2A40033, #E2A40033)const AstryxColorToken('--color-background-yellow') - borderYellow → const AstryxColorToken
-
The
--color-border-yellowtoken.Default:
light-dark(#C58600, #B47700)const AstryxColorToken('--color-border-yellow') - iconYellow → const AstryxColorToken
-
The
--color-icon-yellowtoken.Default:
light-dark(#FBC02D, #FFEE58)const AstryxColorToken('--color-icon-yellow') - textYellow → const AstryxColorToken
-
The
--color-text-yellowtoken.Default:
light-dark(#753F07, #FBCE03)const AstryxColorToken('--color-text-yellow')
Properties
- cssName → String
-
The upstream CSS custom property name, such as
--color-accent.final - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AstryxColorToken> - A constant List of the values in this enum, in order of their declaration.