AstryxContrastLevel enum

The contrast level applied to text and UI tone assignments.

Inheritance
Available extensions

Values

standard → const AstryxContrastLevel

Upstream's default. Primary text at tone 10 (light) and 90 (dark).

high → const AstryxContrastLevel

Pushes text tones to the extremes — 0 and 99 for primary text.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AstryxContrastLevel>
A constant List of the values in this enum, in order of their declaration.