AstryxMotionScaleConfig class

Configuration for the motion scale.

{@tool snippet}

// The default Astryx motion scale.
const AstryxMotionScaleConfig(
  fast: 175,
  medium: 410,
  slow: 975,
  ratio: 0.75,
);

{@end-tool}

Annotations

Constructors

AstryxMotionScaleConfig({required double fast, required double medium, required double ratio, double? slow, String? easing})
Creates a motion scale configuration.
const

Properties

easing String?
An optional easing curve overriding --ease-standard.
final
fast double
Base duration for micro-interactions, in milliseconds — hover, toggle, checkbox.
final
hashCode int
The hash code for this object.
no setteroverride
medium double
Base duration for entrance and exit animations, in milliseconds — dialog, drawer, panel.
final
ratio double
Scaling ratio for the min and max variants of each band.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slow double?
Base duration for slow, continuous animations, in milliseconds — spinner, progress.
final

Methods

copyWith({double? fast, double? medium, double? ratio, double? slow, String? easing}) AstryxMotionScaleConfig
Returns a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override