AstryxRadiusToken enum

Corner radii, in logical pixels.

7 tokens. cssName is the upstream CSS custom property and is the join key against dev/fixtures/tokens.json.

Inheritance
Implemented types
Available extensions

Values

none → const AstryxRadiusToken

The --radius-none token.

Default: 0px

const AstryxRadiusToken('--radius-none')
inner → const AstryxRadiusToken

The --radius-inner token.

Default: 4px

const AstryxRadiusToken('--radius-inner')
element → const AstryxRadiusToken

The --radius-element token.

Default: 8px

const AstryxRadiusToken('--radius-element')
container → const AstryxRadiusToken

The --radius-container token.

Default: 12px

const AstryxRadiusToken('--radius-container')
page → const AstryxRadiusToken

The --radius-page token.

Default: 28px

const AstryxRadiusToken('--radius-page')
chat → const AstryxRadiusToken

The --radius-chat token.

Default: 28px

const AstryxRadiusToken('--radius-chat')
full → const AstryxRadiusToken

The --radius-full token.

Default: 9999px

const AstryxRadiusToken('--radius-full')

Properties

cssName String
The upstream CSS custom property name, such as --color-accent.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AstryxRadiusToken>
A constant List of the values in this enum, in order of their declaration.