AstryxIconTheme class
Visual configuration for AstryxIcon.
- Annotations
Constructors
- AstryxIconTheme({Color? color, double? size, double? opticalSizeAdjustment})
-
Creates an icon theme.
const
Properties
- color → Color?
-
The default colour, when an instance names no semantic colour.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- opticalSizeAdjustment → double?
-
Added to the resolved size.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double?
-
Overrides the resolved size, in logical pixels.
final
Methods
-
copyWith(
{Color? color, double? size, double? opticalSizeAdjustment}) → AstryxIconTheme - Returns a copy with the given fields replaced.
-
merge(
AstryxIconTheme? other) → AstryxIconTheme -
Returns a copy with every non-null field of
otherapplied over this. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
AstryxIconTheme? a, AstryxIconTheme? b, double t) → AstryxIconTheme? - Linearly interpolates between two icon themes.