AstryxRadiusToken enum
Corner radii, in logical pixels.
7 tokens. cssName is the upstream CSS custom property and
is the join key against dev/fixtures/tokens.json.
- Inheritance
- Implemented types
- Available extensions
Values
- none → const AstryxRadiusToken
-
The
--radius-nonetoken.Default:
0pxconst AstryxRadiusToken('--radius-none') - inner → const AstryxRadiusToken
-
The
--radius-innertoken.Default:
4pxconst AstryxRadiusToken('--radius-inner') - element → const AstryxRadiusToken
-
The
--radius-elementtoken.Default:
8pxconst AstryxRadiusToken('--radius-element') - container → const AstryxRadiusToken
-
The
--radius-containertoken.Default:
12pxconst AstryxRadiusToken('--radius-container') - page → const AstryxRadiusToken
-
The
--radius-pagetoken.Default:
28pxconst AstryxRadiusToken('--radius-page') - chat → const AstryxRadiusToken
-
The
--radius-chattoken.Default:
28pxconst AstryxRadiusToken('--radius-chat') - full → const AstryxRadiusToken
-
The
--radius-fulltoken.Default:
9999pxconst AstryxRadiusToken('--radius-full')
Properties
- cssName → String
-
The upstream CSS custom property name, such as
--color-accent.final - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AstryxRadiusToken> - A constant List of the values in this enum, in order of their declaration.